@@ -1143,7 +1143,7 @@ void print_summary_hpaSelection(List x) {
 
 	Rprintf("%s", "---\n");
 
-	Rprintf("%s", "Signif. codes:  0 *** 0.001 ** 0.01 * 0.05 . 0.1   1\n");
+	Rprintf("%s", "Signif. codes:  0 '***' 0.001 '**' 0.01 '*' 0.05 '.' 0.1 ' ' 1\n");
 
 	Rprintf("%s", "--------------------------------------------------------------\n");
 }
